@@ -5,22 +5,6 @@ require 'fog/json'
 require File.expand_path('../aws/version', __FILE__)
 
 module Fog
-  module CDN
-    autoload :AWS,  File.expand_path('../aws/cdn', __FILE__)
-  end
-
-  module Compute
-    autoload :AWS, File.expand_path('../aws/compute', __FILE__)
-  end
-
-  module DNS
-    autoload :AWS, File.expand_path('../aws/dns', __FILE__)
-  end
-
-  module Storage
-    autoload :AWS, File.expand_path('../aws/storage', __FILE__)
-  end
-
   module AWS
     extend Fog::Provider
 
@@ -32,9 +16,12 @@ module Fog
 
     # Services
     autoload :AutoScaling,      File.expand_path('../aws/auto_scaling', __FILE__)
+    autoload :CDN,              File.expand_path('../aws/cdn', __FILE__)
     autoload :CloudFormation,   File.expand_path('../aws/cloud_formation', __FILE__)
     autoload :CloudWatch,       File.expand_path('../aws/cloud_watch', __FILE__)
+    autoload :Compute,          File.expand_path('../aws/compute', __FILE__)
     autoload :DataPipeline,     File.expand_path('../aws/data_pipeline', __FILE__)
+    autoload :DNS,              File.expand_path('../aws/dns', __FILE__)
     autoload :DynamoDB,         File.expand_path('../aws/dynamodb', __FILE__)
     autoload :ECS,              File.expand_path('../aws/ecs', __FILE__)
     autoload :EFS,              File.expand_path('../aws/efs', __FILE__)
@@ -54,6 +41,7 @@ module Fog
     autoload :SNS,              File.expand_path('../aws/sns', __FILE__)
     autoload :SQS,              File.expand_path('../aws/sqs', __FILE__)
     autoload :STS,              File.expand_path('../aws/sts', __FILE__)
+    autoload :Storage,          File.expand_path('../aws/storage', __FILE__)
     autoload :Support,          File.expand_path('../aws/support', __FILE__)
     autoload :SimpleDB,         File.expand_path('../aws/simpledb', __FILE__)
 
@@ -207,7 +195,7 @@ module Fog
         options = group_name
       elsif group_name
         if options.key?('GroupName')
-          raise Fog::Compute::AWS::Error, 'Arguments specified both group_name and GroupName in options'
+          raise Fog::AWS::Compute::Error, 'Arguments specified both group_name and GroupName in options'
         end
         options = options.clone
         options['GroupName'] = group_name
@@ -215,7 +203,7 @@ module Fog
       name_specified = options.key?('GroupName') && !options['GroupName'].nil?
       group_id_specified = options.key?('GroupId') && !options['GroupId'].nil?
       unless name_specified || group_id_specified
-        raise Fog::Compute::AWS::Error, 'Neither GroupName nor GroupId specified'
+        raise Fog::AWS::Compute::Error, 'Neither GroupName nor GroupId specified'
       end
       if name_specified && group_id_specified
         options.delete('GroupName')
@@ -229,7 +217,20 @@ module Fog
     end
 
     def self.regions
-      @regions ||= ['ap-northeast-1', 'ap-northeast-2', 'ap-southeast-1', 'ap-southeast-2', 'eu-central-1', 'ca-central-1', 'eu-west-1', 'eu-west-2', 'eu-west-3', 'us-east-1', 'us-east-2', 'us-west-1', 'us-west-2', 'sa-east-1', 'cn-north-1', 'us-gov-west-1', 'ap-south-1']
+      @regions ||= [
+        'ap-northeast-1', 'ap-northeast-2', 'ap-northeast-3',
+        'ap-south-1',
+        'ap-southeast-1', 'ap-southeast-2',
+        'ca-central-1',
+        'cn-north-1',
+        'cn-northwest-1',
+        'eu-central-1',
+        'eu-west-1', 'eu-west-2', 'eu-west-3',
+        'us-east-1', 'us-east-2',
+        'us-west-1', 'us-west-2',
+        'sa-east-1',
+        'us-gov-west-1'
+      ]
     end
 
     def self.validate_region!(region, host=nil)
