@@ -1,6 +1,6 @@
 module Fog
-  module Compute
-    class AWS
+  module AWS
+    class Compute
       class Real
         require 'fog/aws/parsers/compute/describe_security_groups'
 
@@ -38,7 +38,7 @@ module Fog
           request({
             'Action'    => 'DescribeSecurityGroups',
             :idempotent => true,
-            :parser     => Fog::Parsers::Compute::AWS::DescribeSecurityGroups.new
+            :parser     => Fog::Parsers::AWS::Compute::DescribeSecurityGroups.new
           }.merge!(params))
         end
       end
