@@ -1,6 +1,6 @@
 module Fog
-  module Storage
-    class AWS
+  module AWS
+    class Storage
       class Real
         # Create an object in an S3 bucket
         #
@@ -57,14 +57,14 @@ module Fog
 
       class Mock # :nodoc:all
         require 'fog/aws/requests/storage/shared_mock_methods'
-        include Fog::Storage::AWS::SharedMockMethods
+        include Fog::AWS::Storage::SharedMockMethods
 
         def put_object(bucket_name, object_name, data, options = {})
           define_mock_acl(bucket_name, object_name, options)
 
           data = parse_mock_data(data)
           headers = data[:headers].merge!(options)
-          Fog::Storage::AWS::Real.conforming_to_us_ascii! headers.keys.grep(/^x-amz-meta-/), headers
+          Fog::AWS::Storage::Real.conforming_to_us_ascii! headers.keys.grep(/^x-amz-meta-/), headers
           bucket = verify_mock_bucket_exists(bucket_name)
 
           options['Content-Type'] ||= data[:headers]['Content-Type']
