@@ -1,6 +1,6 @@
 module Fog
-  module Storage
-    class AWS < Fog::Service
+  module AWS
+    class Storage < Fog::Service
       extend Fog::AWS::CredentialFetcher::ServiceMethods
 
       COMPLIANT_BUCKET_NAMES = /^(?:[a-z]|\d(?!\d{0,2}(?:\.\d{1,3}){3}$))(?:[a-z0-9]|\.(?![\.\-])|\-(?![\.])){1,61}[a-z0-9]$/
@@ -130,7 +130,7 @@ module Fog
         end
 
         def url(params, expires)
-          Fog::Logger.deprecation("Fog::Storage::AWS => #url is deprecated, use #https_url instead [light_black](#{caller.first})[/]")
+          Fog::Logger.deprecation("Fog::AWS::Storage => #url is deprecated, use #https_url instead [light_black](#{caller.first})[/]")
           https_url(params, expires)
         end
 
@@ -221,8 +221,8 @@ module Fog
           case region.to_s
           when DEFAULT_REGION, ''
             's3.amazonaws.com'
-          when 'cn-north-1'
-            's3.cn-north-1.amazonaws.com.cn'
+          when %r{\Acn-.*}
+            "s3.#{region}.amazonaws.com.cn"
           else
             "s3-#{region}.amazonaws.com"
           end
@@ -316,7 +316,8 @@ module Fog
         def params_to_url(params)
           query = params[:query] && params[:query].map do |key, value|
             if value
-              [key, escape(value.to_s)].join('=')
+              # URL parameters need / to be escaped
+              [key, Fog::AWS.escape(value.to_s)].join('=')
             else
               key
             end
@@ -763,4 +764,17 @@ DATA
       end
     end
   end
+
+  # @deprecated
+  module Storage
+    # @deprecated
+    class AWS < Fog::AWS::Storage
+      # @deprecated
+      # @overrides Fog::Service.new (from the fog-core gem)
+      def self.new(*)
+        Fog::Logger.deprecation 'Fog::Storage::AWS is deprecated, please use Fog::AWS::Storage.'
+        super
+      end
+    end
+  end
 end
