@@ -24,9 +24,9 @@ DESCRIBE_IMAGES_RESULT = <<-EOF
 </DescribeImagesResponse>
 EOF
 
-Shindo.tests('Compute::AWS | parsers | describe_images', ['compute', 'aws', 'parser']) do
+Shindo.tests('AWS::Compute | parsers | describe_images', ['compute', 'aws', 'parser']) do
   tests('parses the xml').formats(AWS::Compute::Formats::DESCRIBE_IMAGES) do
-    parser = Nokogiri::XML::SAX::Parser.new(Fog::Parsers::Compute::AWS::DescribeImages.new)
+    parser = Nokogiri::XML::SAX::Parser.new(Fog::Parsers::AWS::Compute::DescribeImages.new)
     parser.parse(DESCRIBE_IMAGES_RESULT)
     parser.document.response
   end
